#ifndef LIBPDFTOIMAGE_HELP_H
#define LIBPDFTOIMAGE_HELP_H

#include <iostream>


class Help {

public:

    static void showHelp(const std::string& option);

};

#endif //LIBPDFTOIMAGE_HELP_H